@@ -3,7 +3,7 @@
 from __future__ import absolute_import, unicode_literals
 
 __author__  = 'Jefurry <jefurry@qq.com>'
-__version__ = '0.1.4'
+__version__ = '0.1.5'
 
 import traceback
 from sqlbuilder import smartsql as sb
@@ -159,7 +159,7 @@ class Model(ModelBase):
     def all(self, sql):
         try:
             _res = self._select(sql, 'select_all')
-            if len(_res) <= 0:
+            if not _res or len(_res) <= 0:
                 return None
             return result.Result.new(_res)
         except Exception as e:
@@ -170,7 +170,7 @@ class Model(ModelBase):
     def first(self, sql):
         try:
             _res = self._select(sql, 'select_one')
-            if len(_res) <= 0:
+            if not _res or len(_res) <= 0:
                 return None
             return result.RowResult.new(_res)
         except Exception as e:
@@ -182,7 +182,7 @@ class Model(ModelBase):
     def count(self, sql):
         try:
             _res = self._select(sql, 'select_count')
-            if len(_res) <= 0:
+            if not _res or len(_res) <= 0:
                 return 0
             for key in _res:
                 return _res[key]
@@ -228,13 +228,18 @@ class Model(ModelBase):
         del self
         if _traceback is not None:
             if _debug:
-                print traceback.format_exc()
+                print "with exit error: ", traceback.format_exc()
             return False
         return True
 
 
 if __name__ == '__main__':
     import time, sys
+
+    pyar.settings.DNS = {
+    'default' : 'mysql://root:@localhost:3306/davos?use_unicode=0&charset=utf8&mincached=20&maxcached=100',
+    }
+
     class DavosDatabase(Model):
         _debug_ = True
         _using_ = 'default'
